@@ -17,6 +17,7 @@ import unittest
 import getopt
 
 from email.test import test_email
+from email.test import test_email_renamed
 
 from test.test_support import TestSkipped
 try:
@@ -27,6 +28,7 @@ except TestSkipped:
 # See if we have the Japanese codecs package installed
 try:
     from email.test import test_email_codecs
+    from email.test import test_email_codecs_renamed
 except TestSkipped:
     test_email_codecs = None
 
@@ -35,8 +37,10 @@ except TestSkipped:
 def suite():
     suite = unittest.TestSuite()
     suite.addTest(test_email.suite())
+    suite.addTest(test_email_renamed.suite())
     if test_email_codecs is not None:
         suite.addTest(test_email_codecs.suite())
+        suite.addTest(test_email_codecs_renamed.suite())
     if test_email_torture is not None:
         suite.addTest(test_email_torture.suite())
     return suite
